{ pkgs, ... }:
{
  services.swayidle = {
    enable = true;
    systemdTarget = "graphical-session.target";
    extraArgs = [ "-w" ];
    events = [
      {
        event = "lock";
        command = "/run/current-system/sw/bin/pidof swaylock || ${pkgs.swaylock}/bin/swaylock";
      }
      # {
      #   event = "before-sleep";
      #   command = "/home/emenel/.local/bin/session-lock";
      # }
      {
        event = "after-resume";
        command = "/home/emenel/.local/bin/on-unlock";
      }
    ];

    timeouts = [
      {
        timeout = 60;
        command = "/home/emenel/.local/bin/dim-all-monitors";
        resumeCommand = "/home/emenel/.local/bin/on-unlock";
      }

      # battery timers
      {
        timeout = 90;
        command = "${pkgs.systemd}/bin/systemd-ac-power || ${pkgs.systemd}/bin/loginctl lock-session";
      }
      {
        timeout = 120;
        command = "${pkgs.systemd}/bin/systemd-ac-power || ${pkgs.niri-unstable}/bin/niri msg action power-off-monitors";
      }
      {
        timeout = 180;
        command = "${pkgs.systemd}/bin/systemd-ac-power || ${pkgs.systemd}/bin/systemctl suspend";
      }

      # ac power timers
      {
        timeout = 180;
        command = "${pkgs.systemd}/bin/systemd-ac-power && ${pkgs.systemd}/bin/loginctl lock-session";
      }

      {
        timeout = 240;
        command = "${pkgs.systemd}/bin/systemd-ac-power && ${pkgs.niri-unstable}/bin/niri msg action power-off-monitors";
      }

      {
        timeout = 600;
        command = "${pkgs.systemd}/bin/systemd-ac-power && ${pkgs.systemd}/bin/systemctl suspend";
      }
    ];

  };


  programs.swaylock = {
    enable = true;
    settings = {
      color = "000000";
      font-size = 32;
      indicator-idle-visible = true;
      indicator-radius = 150;
      line-color = "cccccc";
      show-failed-attempts = true;
    };
  };
}
